@@ -148,7 +148,9 @@ class ScratchRealization(object):
                 "FULLPATH": os.path.join(abspath, "STATUS"),
                 "BASENAME": "STATUS",
             }
-            self.files = self.files.append(filerow, ignore_index=True)
+            self.files = pd.concat(
+                [self.files, pd.DataFrame([filerow])], ignore_index=True
+            )
             self.load_status()
         else:
             logger.warning("No STATUS file, %s", abspath)
@@ -160,7 +162,9 @@ class ScratchRealization(object):
                 "FULLPATH": os.path.join(abspath, "jobs.json"),
                 "BASENAME": "jobs.json",
             }
-            self.files = self.files.append(filerow, ignore_index=True)
+            self.files = pd.concat(
+                [self.files, pd.DataFrame([filerow])], ignore_index=True
+            )
 
         if os.path.exists(os.path.join(abspath, "OK")):
             self.load_scalar("OK")
@@ -315,7 +319,9 @@ class ScratchRealization(object):
                 "FULLPATH": fullpath,
                 "BASENAME": os.path.split(localpath)[-1],
             }
-            self.files = self.files.append(filerow, ignore_index=True)
+            self.files = pd.concat(
+                [self.files, pd.DataFrame([filerow])], ignore_index=True
+            )
         try:
             value = pd.read_csv(
                 fullpath,
@@ -391,7 +397,9 @@ class ScratchRealization(object):
                 "FULLPATH": fullpath,
                 "BASENAME": os.path.split(localpath)[-1],
             }
-            self.files = self.files.append(filerow, ignore_index=True)
+            self.files = pd.concat(
+                [self.files, pd.DataFrame([filerow])], ignore_index=True
+            )
         try:
             keyvalues = pd.read_csv(
                 fullpath,
@@ -444,7 +452,9 @@ class ScratchRealization(object):
                 "FULLPATH": fullpath,
                 "BASENAME": os.path.split(localpath)[-1],
             }
-            self.files = self.files.append(filerow, ignore_index=True)
+            self.files = pd.concat(
+                [self.files, pd.DataFrame([filerow])], ignore_index=True
+            )
         try:
             if convert_numeric:
                 # Trust that Pandas will determine sensible datatypes
@@ -490,6 +500,7 @@ class ScratchRealization(object):
             # to be present.
             return pd.DataFrame()  # will be empty
         errorcolumns = ["error" + str(x) for x in range(0, 10)]
+
         status = pd.read_csv(
             statusfile,
             sep=r"\s+",
@@ -499,8 +510,7 @@ class ScratchRealization(object):
             + errorcolumns,
             dtype=str,
             engine="python",
-            error_bad_lines=False,
-            warn_bad_lines=True,
+            on_bad_lines="skip",
         )
 
         # dtype str messes up a little bit, pre-Pandas 0.24.1 gives 'None' as
@@ -823,8 +833,12 @@ class ScratchRealization(object):
                     self.files = self.files[self.files["FULLPATH"] != absmatch]
                 if metadata:
                     filerow.update(metadata)
-                self.files = self.files.append(filerow, ignore_index=True)
-                returnedslice = returnedslice.append(filerow, ignore_index=True)
+                self.files = pd.concat(
+                    [self.files, pd.DataFrame([filerow])], ignore_index=True
+                )
+                returnedslice = pd.concat(
+                    [returnedslice, pd.DataFrame([filerow])], ignore_index=True
+                )
         return returnedslice
 
     @property
