@@ -363,8 +363,8 @@ class VirtualRealization(object):
         # Add the extra datetimes to interpolate at.
         smry.set_index("DATE", inplace=True)
         smry.index = pd.to_datetime(smry.index)
-        smry = smry.append(
-            pd.DataFrame(index=pd.to_datetime(time_index_dt)), sort=False
+        smry = pd.concat(
+            [smry, pd.DataFrame(index=pd.to_datetime(time_index_dt))], sort=False
         )
         # Drop duplicated dates. It is always the first one which is the
         # original.
